Stable wire names for host-dispatched mobile MVP actions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- callSecureApi → const String
- openMiniProgramScreen → const String
- openNativeScreen → const String
- popMiniProgramScreen → const String
- popToMiniProgramRoot → const String
- popToMiniProgramScreen → const String
- replaceMiniProgramScreen → const String
- resetMiniProgramStack → const String
- trackEvent → const String