OpenNativeScreenActionPayload class abstract

Payload for a host-controlled native navigation request.

Available extensions
Annotations
  • @freezed

Constructors

OpenNativeScreenActionPayload({required String route, @Default.new(<String, dynamic>{}) Map<String, dynamic> args, @Default.new(false) bool expectResult})
const
factory
OpenNativeScreenActionPayload.fromJson(Map<String, dynamic> json)
factory

Properties

args Map<String, dynamic>
no setterinherited
copyWith → $OpenNativeScreenActionPayloadCopyWith<OpenNativeScreenActionPayload>
Create a copy of OpenNativeScreenActionPayload with the given fields replaced by the non-null parameter values.
no setterinherited
expectResult bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
route String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OpenNativeScreenActionPayload value)) → TResult

Available on OpenNativeScreenActionPayload, provided by the OpenNativeScreenActionPayloadPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OpenNativeScreenActionPayload value)?) → TResult?

Available on OpenNativeScreenActionPayload, provided by the OpenNativeScreenActionPayloadPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OpenNativeScreenActionPayload value)?, {required TResult orElse()}) → TResult

Available on OpenNativeScreenActionPayload, provided by the OpenNativeScreenActionPayloadPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String route, Map<String, dynamic> args, bool expectResult)?, {required TResult orElse()}) → TResult

Available on OpenNativeScreenActionPayload, provided by the OpenNativeScreenActionPayloadPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this OpenNativeScreenActionPayload to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String route, Map<String, dynamic> args, bool expectResult)) → TResult

Available on OpenNativeScreenActionPayload, provided by the OpenNativeScreenActionPayloadPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String route, Map<String, dynamic> args, bool expectResult)?) → TResult?

Available on OpenNativeScreenActionPayload, provided by the OpenNativeScreenActionPayloadPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited