TrackEventActionPayload class abstract
Payload for a host-controlled analytics event dispatch.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TrackEventActionPayload({required String name, @Default.new(<String, dynamic>{}) Map<
String, dynamic> properties}) -
constfactory
-
TrackEventActionPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $TrackEventActionPayloadCopyWith<
TrackEventActionPayload> -
Create a copy of TrackEventActionPayload
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setterinherited
-
properties
→ Map<
String, dynamic> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TrackEventActionPayload value)) → TResult -
Available on TrackEventActionPayload, provided by the TrackEventActionPayloadPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TrackEventActionPayload value)?) → TResult? -
Available on TrackEventActionPayload, provided by the TrackEventActionPayloadPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TrackEventActionPayload value)?, {required TResult orElse()}) → TResult -
Available on TrackEventActionPayload, provided by the TrackEventActionPayloadPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String name, Map< String, dynamic> properties)?, {required TResult orElse()}) → TResult -
Available on TrackEventActionPayload, provided by the TrackEventActionPayloadPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TrackEventActionPayload to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String name, Map< String, dynamic> properties)) → TResult -
Available on TrackEventActionPayload, provided by the TrackEventActionPayloadPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String name, Map< String, dynamic> properties)?) → TResult? -
Available on TrackEventActionPayload, provided by the TrackEventActionPayloadPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited