Capability enum

Deprecated enum kept for existing source compatibility.

New code should use CapabilityId strings and CapabilityIds.

Inheritance
Available extensions
Annotations
  • @Deprecated('Use CapabilityId strings and CapabilityIds instead.')
  • @JsonEnum.new()

Values

auth → const Capability

Authentication capability.

analytics → const Capability

Analytics capability.

secureApi → const Capability

Secure API capability.

nativeNavigation → const Capability

Native navigation capability.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireValue String

Available on Capability, provided by the CapabilityX extension

Stable wire value used in manifests and compatibility checks.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Capability>
A constant List of the values in this enum, in order of their declaration.