CapabilityIdListConverter class

JSON converter that validates manifest capability IDs.

Constructors

CapabilityIdListConverter()
Creates a capability ID list converter.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Object? json) List<CapabilityId>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(List<CapabilityId> object) Object
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited