normalizeAll static method
Normalizes a list of capability values for constructors and JSON.
Implementation
static List<CapabilityId> normalizeAll(Iterable<Object?> values) =>
values.map(normalizeObject).toList(growable: false);
Normalizes a list of capability values for constructors and JSON.
static List<CapabilityId> normalizeAll(Iterable<Object?> values) =>
values.map(normalizeObject).toList(growable: false);