systemShare constant
String
const systemShare
Host can open the platform share chooser for accepted inert content.
Implementation
static const CapabilityId systemShare = 'share.system';
Host can open the platform share chooser for accepted inert content.
static const CapabilityId systemShare = 'share.system';