isCancelled property
bool
get
isCancelled
Whether the user or host cancelled the operation without success.
Implementation
bool get isCancelled => status == HostActionStatus.cancelled;
Whether the user or host cancelled the operation without success.
bool get isCancelled => status == HostActionStatus.cancelled;