MiniProgramCacheMode enum

Contract-level cache behavior for a manifest or screen payload.

staleWhileError means the SDK should prefer fresh network data but may use a previously cached copy when backend loading fails for a retryable reason. noCache means the SDK must not persist or reuse cached copies.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

staleWhileError → const MiniProgramCacheMode
noCache → const MiniProgramCacheMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MiniProgramCacheMode>
A constant List of the values in this enum, in order of their declaration.