allowsStaleCache property
bool
get
allowsStaleCache
Whether stale cached content may be reused for this payload.
Implementation
bool get allowsStaleCache => mode == MiniProgramCacheMode.staleWhileError;
Whether stale cached content may be reused for this payload.
bool get allowsStaleCache => mode == MiniProgramCacheMode.staleWhileError;