hasFeatureFlag method
Whether the manifest declares the given feature flag key.
Implementation
bool hasFeatureFlag(FeatureFlagKey key) => featureFlags.contains(key);
Whether the manifest declares the given feature flag key.
bool hasFeatureFlag(FeatureFlagKey key) => featureFlags.contains(key);