MiniProgramFileTransferProgress class

JSON-safe progress reported by an active upload or download.

Constructors

MiniProgramFileTransferProgress({required String transferId, required MiniProgramFileTransferDirection direction, required MiniProgramFileTransferStatus status, required int bytesTransferred, int? totalBytes, String? fileName})

Properties

bytesTransferred int
final
direction MiniProgramFileTransferDirection
final
fileName String?
final
fraction double?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MiniProgramFileTransferStatus
final
totalBytes int?
final
transferId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited