MiniProgramLocationResult class

JSON-safe result returned by a host current-location provider.

Constructors

MiniProgramLocationResult({required double latitude, required double longitude, required double accuracyMeters, required DateTime capturedAtUtc, String source = deviceSource})
const
MiniProgramLocationResult.fromJson(Map<String, dynamic> json)
factory

Properties

accuracyMeters double
final
capturedAtUtc DateTime
final
hashCode int
The hash code for this object.
no setterinherited
latitude double
final
longitude double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

deviceSource → const String