MiniProgramMediaPlaybackSnapshot class final

JSON-safe playback snapshot. It intentionally contains no URL or headers.

Constructors

MiniProgramMediaPlaybackSnapshot({required String playerId, required MiniProgramMediaPlaybackKind kind, required MiniProgramMediaPlaybackStatus status, Duration position = Duration.zero, Duration? duration, Duration buffered = Duration.zero, double volume = 1, double speed = 1, bool muted = false})
MiniProgramMediaPlaybackSnapshot.fromJson(Map<String, dynamic> json)
factory

Properties

buffered Duration
final
duration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
kind MiniProgramMediaPlaybackKind
final
muted bool
final
playerId String
final
position Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final
status MiniProgramMediaPlaybackStatus
final
volume double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited