MiniProgramQrScanResult class

JSON-safe result returned by a trusted host QR scanner.

rawValue is inert data. The SDK never opens URLs or executes content based on valueType.

Constructors

MiniProgramQrScanResult({required String rawValue, required String valueType, required DateTime scannedAtUtc, String format = qrFormat})
MiniProgramQrScanResult.fromJson(Map<String, dynamic> json)
factory

Properties

format String
final
hashCode int
The hash code for this object.
no setterinherited
rawValue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scannedAtUtc DateTime
final
valueType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

qrFormat → const String
supportedValueTypes → const Set<String>