validate method
void
validate()
Implementation
void validate() {
if (!chooserOpened) {
throw const FormatException(
'Mini-program share result must confirm that the chooser opened.',
);
}
}
void validate() {
if (!chooserOpened) {
throw const FormatException(
'Mini-program share result must confirm that the chooser opened.',
);
}
}