invalidJson constant
String
const invalidJson
A smoke route did not return the expected JSON object.
Implementation
static const String invalidJson = 'publisher_backend_invalid_json';
A smoke route did not return the expected JSON object.
static const String invalidJson = 'publisher_backend_invalid_json';