MiniProgramScreenFormatConverter class
JSON converter that preserves unknown screen formats as strings.
Constructors
- MiniProgramScreenFormatConverter()
-
Creates a screen format converter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJson(
Object? json) → MiniProgramScreenFormat -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
MiniProgramScreenFormat object) → Object -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited