Standard mini-program screen document formats.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isValid(
MiniProgramScreenFormat value) → bool -
Returns whether
valueis a non-empty screen format ID. -
normalize(
MiniProgramScreenFormat value) → MiniProgramScreenFormat - Normalizes and validates a screen format ID.