SdkVersionRange class abstract

Semver range expression describing which SDK versions a manifest supports.

Available extensions
Annotations
  • @freezed

Constructors

SdkVersionRange({required String value})
const
factory
SdkVersionRange.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SdkVersionRangeCopyWith<SdkVersionRange>
Create a copy of SdkVersionRange with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isValid bool

Available on SdkVersionRange, provided by the SdkVersionRangeX extension

Whether the underlying semver range string parses successfully.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
no setterinherited

Methods

allows(String sdkVersion) bool

Available on SdkVersionRange, provided by the SdkVersionRangeX extension

Whether a concrete SDK version is allowed by this semver range.
map<TResult extends Object?>(TResult $default(_SdkVersionRange value)) → TResult

Available on SdkVersionRange, provided by the SdkVersionRangePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SdkVersionRange value)?) → TResult?

Available on SdkVersionRange, provided by the SdkVersionRangePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SdkVersionRange value)?, {required TResult orElse()}) → TResult

Available on SdkVersionRange, provided by the SdkVersionRangePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String value)?, {required TResult orElse()}) → TResult

Available on SdkVersionRange, provided by the SdkVersionRangePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SdkVersionRange to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
tryParseConstraint() → VersionConstraint?

Available on SdkVersionRange, provided by the SdkVersionRangeX extension

Parses the semver range or returns null when the expression is invalid.
tryParseVersion(String sdkVersion) → Version?

Available on SdkVersionRange, provided by the SdkVersionRangeX extension

Parses a concrete SDK version or returns null when it is invalid.
when<TResult extends Object?>(TResult $default(String value)) → TResult

Available on SdkVersionRange, provided by the SdkVersionRangePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String value)?) → TResult?

Available on SdkVersionRange, provided by the SdkVersionRangePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited