Stable wire names for host-dispatched mobile MVP actions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- audioGetStatus → const String
- audioPause → const String
- audioPlay → const String
- audioPreload → const String
- audioRelease → const String
- audioSeek → const String
- audioSetSpeed → const String
- audioSetVolume → const String
- audioStop → const String
- callSecureApi → const String
- cameraCancel → const String
- cameraCapturePhoto → const String
- fileCancel → const String
- fileDownload → const String
- fileUpload → const String
- flashlightGetStatus → const String
- flashlightToggle → const String
- flashlightTurnOff → const String
- flashlightTurnOn → const String
- locationGetCurrent → const String
- mediaRelease → const String
- openMiniProgramScreen → const String
- openNativeScreen → const String
- popMiniProgramScreen → const String
- popToMiniProgramRoot → const String
- popToMiniProgramScreen → const String
- qrScan → const String
- replaceMiniProgramScreen → const String
- resetMiniProgramStack → const String
- trackEvent → const String
- videoEnterFullscreen → const String
- videoExitFullscreen → const String
- videoGetStatus → const String
- videoPause → const String
- videoPlay → const String
- videoRelease → const String
- videoSeek → const String
- videoSetMuted → const String
- videoSetSpeed → const String
- videoSetVolume → const String
- videoStop → const String