Capability enum
Host capabilities that a mini-program can require before rendering.
- Inheritance
- Available extensions
- Annotations
-
- @JsonEnum.new()
Values
- auth → const Capability
- analytics → const Capability
- secureApi → const Capability
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
Available on Capability, provided by the CapabilityX extension
Stable wire value used in manifests and compatibility checks.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Capability> - A constant List of the values in this enum, in order of their declaration.