Stable error code constants shared across contracts, SDK, and hosts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- actionCallLimitExceeded → const String
- actionNotFound → const String
- backendTimeout → const String
- backendUnreachable → const String
- conditionInvalidValue → const String
- dataInvalidJson → const String
- dataInvalidQuery → const String
- dataResourceNotFound → const String
- dataResourceTooLarge → const String
- dataSearchFailed → const String
- endpointNotConfigured → const String
- initializeFailed → const String
- invalidResultPayload → const String
- locationInvalidResult → const String
- locationNotAccepted → const String
- locationPermissionDenied → const String
- locationPermissionDeniedPermanently → const String
- locationRequestInProgress → const String
- locationServiceDisabled → const String
- locationTimeout → const String
- manifestParseFailure → const String
- mathComplexityExceeded → const String
- mathDivisionByZero → const String
- mathDomainError → const String
- mathEmptyValues → const String
- mathInvalidExpression → const String
- mathInvalidOperand → const String
- mathInvalidRange → const String
- mathResultNotFinite → const String
- publisherApiDisabled → const String
- screenNotFound → const String
- screenNotInStack → const String
- secureApiForbidden → const String
- secureApiInvalidPayload → const String
- secureApiNotAllowlisted → const String
- secureApiSessionExpired → const String
- secureApiSessionMissing → const String
- secureApiValidationFailed → const String
- stateIndexOutOfRange → const String
- stateInvalidValue → const String
- stateLimitExceeded → const String
- unknownAction → const String
- unsupportedCapability → const String
- unsupportedContractVersion → const String
- unsupportedSdkVersion → const String