Stable error code constants shared across contracts, SDK, and hosts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backendTimeout → const String
- backendUnreachable → const String
- invalidResultPayload → const String
- manifestParseFailure → const String
- screenNotFound → const String
- screenNotInStack → const String
- secureApiForbidden → const String
- secureApiInvalidPayload → const String
- secureApiNotAllowlisted → const String
- secureApiSessionExpired → const String
- secureApiSessionMissing → const String
- secureApiValidationFailed → const String
- unknownAction → const String
- unsupportedCapability → const String
- unsupportedContractVersion → const String
- unsupportedSdkVersion → const String