MiniProgramCacheRuleConverter class
Backward-compatible cache-rule converter for manifest cache policy fields.
Older manifests may still serialize cache policy values as simple strings,
for example "staleWhileError". Newer manifests may use the object form
with a mode plus an explicit maxStaleSeconds limit.
Constructors
- MiniProgramCacheRuleConverter()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJson(
Object? json) → MiniProgramCacheRule -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
MiniProgramCacheRule object) → Object -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited