MiniProgramManifestX extension
Properties
- allowsEntryScreenStaleCache → bool
-
Available on MiniProgramManifest, provided by the MiniProgramManifestX extension
Whether the entry screen may be reused from stale cache on backend errors.no setter - allowsManifestStaleCache → bool
-
Available on MiniProgramManifest, provided by the MiniProgramManifestX extension
Whether the manifest itself may be reused from stale cache on backend errors.no setter - entryScreenMaxStaleAge → Duration
-
Available on MiniProgramManifest, provided by the MiniProgramManifestX extension
Maximum allowed stale age for entry-screen reuse after retryable failures.no setter - manifestMaxStaleAge → Duration
-
Available on MiniProgramManifest, provided by the MiniProgramManifestX extension
Maximum allowed stale age for manifest reuse after retryable failures.no setter
Methods
-
hasFeatureFlag(
FeatureFlagKey key) → bool -
Available on MiniProgramManifest, provided by the MiniProgramManifestX extension
Whether the manifest declares the given feature flag key. -
requiresCapability(
Capability capability) → bool -
Available on MiniProgramManifest, provided by the MiniProgramManifestX extension
Whether the manifest requires a given host capability.