MiniProgramCameraPhotoResult class
JSON-safe metadata for a photo captured by a trusted host provider.
mediaRef is an opaque, short-lived host reference. It is not a native path, content URI, or encoded image payload.
Constructors
- MiniProgramCameraPhotoResult({required String captureId, required String mediaRef, required String fileName, required String mimeType, required int bytes, required int width, required int height, required DateTime capturedAtUtc, String source = cameraSource})
-
MiniProgramCameraPhotoResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bytes → int
-
final
- capturedAtUtc → DateTime
-
final
- captureId → String
-
final
- fileName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- mediaRef → String
-
final
- mimeType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cameraSource → const String