MiniProgramPublisherBackendContract class
Provider-neutral Publisher API contract document.
Constructors
-
MiniProgramPublisherBackendContract({int schemaVersion = currentSchemaVersion, String contractVersion = currentContractVersion, required String appId, required Uri backendBaseUri, String healthEndpoint = defaultHealthEndpoint, List<
MiniProgramPublisherBackendSmokeCase> ? smokeTests, bool allowLocalHttp = false}) - Creates a provider-neutral Publisher API contract.
- MiniProgramPublisherBackendContract.fromJson(Object? json, {bool allowLocalHttp = false})
-
Decodes a provider-neutral Publisher API contract.
factory
Properties
- appId → String
-
Mini-program app id.
final
- backendBaseUri → Uri
-
Publisher-owned Publisher API base URL.
final
- contractVersion → String
-
Contract version understood by SDK/tooling.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthEndpoint → String
-
Relative health endpoint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
Contract schema version.
final
-
smokeTests
→ List<
MiniProgramPublisherBackendSmokeCase> -
Smoke cases used by provider-neutral tooling.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the contract to stable JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- currentContractVersion → const String
- Current provider-neutral Publisher API contract version.
- currentSchemaVersion → const int
- Current contract document schema version.
- defaultHealthEndpoint → const String
- Default health route.
- documentType → const String
- Contract document type.