Stable provider-neutral Publisher API error codes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accessKeyInvalid → const String
- Protected Publisher API access rejected the MiniProgram access key.
- accessKeyMissing → const String
- Protected Publisher API access requires a MiniProgram access key.
- invalidContract → const String
- The Publisher API contract file is malformed.
- invalidJson → const String
- A smoke route did not return the expected JSON object.
- timeout → const String
- The Publisher API did not respond before the configured timeout.
- unexpectedStatus → const String
- A smoke route returned an unexpected status.
- unreachable → const String
- The Publisher API could not be reached.