Standard request header names used by Publisher APIs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accessKey → const String
- Partner access key for protected Publisher APIs.
- appId → const String
- Mini-program app id.
- Publisher-owned signed-in user token.
- contractVersion → const String
- Provider-neutral Publisher API contract version.
- hostApp → const String
- Host application identifier.
- hostVersion → const String
- Host application version.
- locale → const String
- Host locale, when available.
- platform → const String
-
Host platform identifier such as
cli,android,ios, orweb. - requestId → const String
- Smoke-test or runtime request identifier.
- sdkVersion → const String
- MiniProgram SDK/runtime version.