MiniProgramPublisherBackendSmokeCase class
Provider-neutral smoke-test route.
Constructors
-
MiniProgramPublisherBackendSmokeCase({required String id, String method = 'GET', required String endpoint, Map<
String, Object?> body = const <String, Object?>{}, MiniProgramPublisherBackendSmokeExpectation? expectation}) - Creates a provider-neutral smoke-test route.
- MiniProgramPublisherBackendSmokeCase.fromJson(Object? json)
-
Decodes a smoke-test route from JSON.
factory
Properties
-
body
→ Map<
String, Object?> -
JSON body for non-GET methods.
final
- endpoint → String
-
Relative Publisher API endpoint.
final
- expectation → MiniProgramPublisherBackendSmokeExpectation
-
Expected route behavior.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable smoke case id.
final
- method → String
-
HTTP method.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes the smoke case to stable JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited