MiniProgramPublisherBackendSmokeExpectation class
Expected provider-neutral smoke-test route behavior.
Constructors
- MiniProgramPublisherBackendSmokeExpectation({int expectedStatus = defaultExpectedStatus, bool expectJsonObject = defaultExpectJsonObject})
-
Creates a smoke-test expectation.
const
Properties
- expectedStatus → int
-
Expected HTTP status.
final
- expectJsonObject → bool
-
Whether response body must decode to a JSON object.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultExpectedStatus → const int
- Default HTTP status expected by smoke tests.
- defaultExpectJsonObject → const bool
- Default response-shape expectation.